#./generate.sh
git add . ../../src/scripting/ecmaapi
git commit . ../../src/scripting/ecmaapi -m "update script bindings"
git push
